use-oci-reference
use-oci-reference provides OCI image reference syntax primitives for names, tags, digests, and canonical references.
It is part of the use-oci RustUse workspace for small, focused OCI primitive crates. It does not perform network calls, shell out to runtimes, implement a registry client, or build container images.
License
Licensed under either of the following, at your option:
- Apache License, Version 2.0
- MIT license
Structs
- Digest
- A parsed OCI digest such as
sha256:<hex>. - Digested
Reference - A name plus digest reference.
- Image
Name - A repository name with an optional registry.
- Image
Reference - A parsed OCI image reference with optional tag and digest.
- Registry
- A registry host label.
- Repository
- A validated repository name.
- TagName
- A validated OCI tag.
- Tagged
Reference - A name plus tag reference.
Enums
- Reference
Error - Errors returned when image references are invalid.
Type Aliases
- Canonical
Reference - A reference that includes a digest.