pub struct TagName(/* private fields */);Expand description
A validated OCI tag.
Implementations
Sourceimpl OciTag
impl OciTag
Sourcepub fn is_version_like(&self) -> bool
pub fn is_version_like(&self) -> bool
Returns true when the tag looks like a simple semantic version.
Sourcepub fn is_architecture_like(&self) -> bool
pub fn is_architecture_like(&self) -> bool
Returns true when the tag contains a common architecture label.